@@ -1,6 +1,6 @@
 ##--------------------------------------------------------------------------##
 ##  File:
-##	$Id: Util.pm,v 1.3 2002/07/09 01:26:24 ehood Exp $
+##	$Id: Util.pm,v 1.4 2002/07/23 03:56:15 ehood Exp $
 ##  Description:
 ##	POD at end of file.
 ##--------------------------------------------------------------------------##
@@ -46,7 +46,7 @@ BEGIN {
 ##--------------------------------------------------------------------------##
 
 sub cmd {
-  print "@_\n" if $ECHO_CMDS;
+  print "@_\n" if $ECHO_CMDS || $ECHO_ONLY;
   if ($ECHO_ONLY) {
     return 0;   # bogus ok exit status
   }
@@ -54,16 +54,16 @@ sub cmd {
 }
 
 sub ch_dir {
-  my $dir       = shift;
+  my $dir = shift;
+  print "chdir $dir\n" if $ECHO_CMDS || $ECHO_ONLY;
   if ($ECHO_ONLY) {
-    print "chdir $dir\n" if $ECHO_CMDS;
-  } else {
-    chdir $dir;
+    return 0;
   }
+  chdir $dir;
 }
 
 sub run_prg {
-  print "@_\n"  if $ECHO_CMDS;
+  print "@_\n"  if $ECHO_CMDS || $ECHO_ONLY;
   if (!$ECHO_ONLY) {
     my $wait = system @_;
     die qq/system @_ failed: $?\n/  if $wait;
@@ -73,8 +73,10 @@ sub run_prg {
 sub mk_dir {
   my $dir       = shift;
   my $mask      = shift;
+  print "mkdir $dir\n"  if $ECHO_CMDS || $ECHO_ONLY;
+
   if ($ECHO_ONLY) {
-    print "mkdir $dir\n"  if $ECHO_CMDS;
+    return 0;
   } else {
     if (defined($mask)) {
       mkdir $dir, $mask;
@@ -85,7 +87,7 @@ sub mk_dir {
 }
 
 sub exec_prg {
-  print "@_\n"  if $ECHO_CMDS;
+  print "@_\n"  if $ECHO_CMDS || $ECHO_ONLY;
   if ($ECHO_ONLY) {
     exit 0;
   } else {
@@ -191,7 +193,7 @@ option to C<Pod::Usage::pod2usage>.
 
 =head1 VERSION
 
-C<$Id: Util.pm,v 1.3 2002/07/09 01:26:24 ehood Exp $>
+C<$Id: Util.pm,v 1.4 2002/07/23 03:56:15 ehood Exp $>
 
 =head1 AUTHOR
 
